@@ -2,7 +2,9 @@ class Constant(object):
     MULTIPLE_COMENT_START_SYMBOL = '/*'
     MULTIPLE_COMENT_END_SYMBOL = '*/'
     SINGLE_COMMENT_SYMBOL = '//'
-    LEFT_BRACE = '{'
-    RIGHT_BRACE = '}'
+    BRACE_LEFT = '{'
+    BRACE_RIGHT = '}'
     EQUAL_SIGN = '='
-    SEMICOLON = ';'
\ No newline at end of file
+    SEMICOLON = ';'
+    ANGLE_BRACKET_LEFT = '<'
+    ANGLE_BRACKET_RIGHT = '>'
